InterceptorChain

Struct InterceptorChain 

pub struct InterceptorChain { /* private fields */ }
An ordered list of CallInterceptors applied to every request.

Interceptors run in registration order for before and reverse order for after (outermost wraps innermost).

Implementations

Source

impl InterceptorChain

pub fn new() -> InterceptorChain

Creates an empty InterceptorChain.

pub fn push<I>(&mut self, interceptor: I)
where I: CallInterceptor,

Adds an interceptor to the end of the chain.

pub fn is_empty(&self) -> bool

Returns true if no interceptors have been registered.

pub async fn run_before( &self, req: &mut ClientRequest, ) -> Result<(), ClientError>

Runs all before hooks in registration order.

Errors

Returns the first error returned by any interceptor in the chain.

pub async fn run_after(&self, resp: &ClientResponse) -> Result<(), ClientError>

Runs all after hooks in reverse registration order.

Errors

Returns the first error returned by any interceptor in the chain.