pub fn new_in_memory_queue() -> (InMemoryQueueWriter, InMemoryQueueReader)Expand description
Creates a new in-memory event queue pair with the default capacity, default max event size, and default write timeout.
pub fn new_in_memory_queue() -> (InMemoryQueueWriter, InMemoryQueueReader)Creates a new in-memory event queue pair with the default capacity, default max event size, and default write timeout.