pub struct InMemoryQueueReader { /* private fields */ }Expand description
In-memory EventQueueReader backed by a broadcast channel receiver.
If the reader falls behind (slower than the writer), missed events are silently skipped and the reader continues with the next available event.
Optionally holds a “pending first event” that is yielded before any
broadcast events. This is used by SubscribeToTask to emit a Task
snapshot as the first event without broadcasting it to all subscribers.
Implementations
Sourceimpl InMemoryQueueReader
impl InMemoryQueueReader
Sourcepub fn set_first_event(&mut self, event: StreamResponse)
pub fn set_first_event(&mut self, event: StreamResponse)
Sets a pending first event to be yielded before broadcast events.