Module message

Module message 

Message types for the A2A protocol.

A Message is the fundamental communication unit between a client and an agent. Each message has a MessageRole (ROLE_USER or ROLE_AGENT) and carries one or more Part values.

Part type discriminator

Part uses a type field discriminator per the A2A spec:

  • {"type": "text", "text": "hi"}
  • {"type": "file", "file": {"name": "f.png", "mimeType": "image/png", "bytes": "..."}}
  • {"type": "data", "data": {...}}

Structs

FileContent
Content of a file part.
Message
A message exchanged between a client and an agent.
MessageId
Opaque unique identifier for a Message.
Part
A content part within a Message or crate::artifact::Artifact.

Enums

MessageRole
The originator of a Message.
PartContent
The content of a Part, discriminated by a type field per the A2A spec.