#[repr(i32)]pub enum Role {
Unspecified = 0,
User = 1,
Agent = 2,
}Expand description
Defines the sender of a message in A2A protocol communication.
Variants
Unspecified = 0
The role is unspecified.
User = 1
The message is from the client to the server.
Agent = 2
The message is from the server to the client.
Implementations
Sourceimpl Role
impl Role
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Role>
pub fn from_str_name(value: &str) -> Option<Role>
Creates an enum from field names used in the ProtoBuf definition.