pub struct AgentExtension {
pub uri: String,
pub description: String,
pub required: bool,
pub params: Option<Struct>,
}Expand description
A declaration of a protocol extension supported by an Agent.
Fields
uri: StringThe unique URI identifying the extension.
description: StringA human-readable description of how this agent uses the extension.
required: boolIf true, the client must understand and comply with the extension’s requirements.
params: Option<Struct>Optional. Extension-specific configuration parameters.