pub struct AgentInterface {
pub url: String,
pub protocol_binding: String,
pub tenant: String,
pub protocol_version: String,
}Expand description
Declares a combination of a target URL, transport and protocol version for interacting with the agent. This allows agents to expose the same functionality over multiple protocol binding mechanisms.
Fields
url: StringThe URL where this interface is available. Must be a valid absolute HTTPS URL in production. Example: “https://api.example.com/a2a/v1", “https://grpc.example.com/a2a"
protocol_binding: StringThe protocol binding supported at this URL. This is an open form string, to be
easily extended for other protocol bindings. The core ones officially
supported are JSONRPC, GRPC and HTTP+JSON.
tenant: StringTenant ID to be used in the request when calling the agent.
protocol_version: StringThe version of the A2A protocol this interface exposes. Use the latest supported minor version per major version. Examples: “0.3”, “1.0”