pub struct OAuthFlows {
pub flow: Option<Flow>,
}Expand description
Defines the configuration for the supported OAuth 2.0 flows.
Fields
flow: Option<Flow>Trait Implementations
Sourceimpl Clone for OAuthFlows
impl Clone for OAuthFlows
Sourcefn clone(&self) -> OAuthFlows
fn clone(&self) -> OAuthFlows
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OAuthFlows
impl Debug for OAuthFlows
Sourceimpl Default for OAuthFlows
impl Default for OAuthFlows
Sourcefn default() -> OAuthFlows
fn default() -> OAuthFlows
Returns the “default value” for a type. Read more
Sourceimpl From<OAuthFlows> for OAuthFlows
impl From<OAuthFlows> for OAuthFlows
Sourcefn from(value: OAuthFlows) -> OAuthFlows
fn from(value: OAuthFlows) -> OAuthFlows
Converts to this type from the input type.
Sourceimpl Message for OAuthFlows
impl Message for OAuthFlows
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for OAuthFlows
impl PartialEq for OAuthFlows
impl StructuralPartialEq for OAuthFlows
Sourceimpl TryFrom<OAuthFlows> for OAuthFlows
impl TryFrom<OAuthFlows> for OAuthFlows
Sourcetype Error = ConvertError
type Error = ConvertError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: OAuthFlows,
) -> Result<OAuthFlows, <OAuthFlows as TryFrom<OAuthFlows>>::Error>
fn try_from( value: OAuthFlows, ) -> Result<OAuthFlows, <OAuthFlows as TryFrom<OAuthFlows>>::Error>
Performs the conversion.