Module push

Module push 

Push notification configuration types.

Push notifications allow an agent to deliver task updates to a client-owned HTTPS webhook endpoint rather than requiring the client to poll. A client registers a TaskPushNotificationConfig for a specific task via the CreateTaskPushNotificationConfig method.

Structs

AuthenticationInfo
Authentication information used by an agent when calling a push webhook.
TaskPushNotificationConfig
Configuration for delivering task updates to a webhook endpoint.