pub struct JsonRpcErrorResponse {
pub jsonrpc: JsonRpcVersion,
pub id: Option<Value>,
pub error: JsonRpcError,
}Expand description
An error JSON-RPC 2.0 response.
Fields
jsonrpc: JsonRpcVersionProtocol version — always "2.0".
id: Option<Value>Matches the id of the corresponding request, or null if the id
could not be determined.
error: JsonRpcErrorStructured error object.
Implementations
Sourceimpl JsonRpcErrorResponse
impl JsonRpcErrorResponse
Sourcepub const fn new(id: Option<Value>, error: JsonRpcError) -> JsonRpcErrorResponse
pub const fn new(id: Option<Value>, error: JsonRpcError) -> JsonRpcErrorResponse
Creates an error response for the given request id.