pub struct JsonRpcRequest {
pub jsonrpc: JsonRpcVersion,
pub id: Option<Value>,
pub method: String,
pub params: Option<Value>,
}Expand description
A JSON-RPC 2.0 request object.
When id is None, the request is a notification and no response is
expected.
Fields
jsonrpc: JsonRpcVersionProtocol version — always "2.0".
id: Option<Value>Request identifier; None for notifications.
method: StringA2A method name (e.g. "message/send").
params: Option<Value>Method-specific parameters.
Implementations
Sourceimpl JsonRpcRequest
impl JsonRpcRequest
Sourcepub fn new(id: Value, method: impl Into<String>) -> JsonRpcRequest
pub fn new(id: Value, method: impl Into<String>) -> JsonRpcRequest
Creates a new request with the given id and method.
Sourcepub fn with_params(
id: Value,
method: impl Into<String>,
params: Value,
) -> JsonRpcRequest
pub fn with_params( id: Value, method: impl Into<String>, params: Value, ) -> JsonRpcRequest
Creates a new request with params.
Sourcepub fn notification(
method: impl Into<String>,
params: Option<Value>,
) -> JsonRpcRequest
pub fn notification( method: impl Into<String>, params: Option<Value>, ) -> JsonRpcRequest
Creates a notification (no id, no response expected).