ErrorCode

Enum ErrorCode 

#[non_exhaustive]
pub enum ErrorCode {
Show 14 variants ParseError = -32_700, InvalidRequest = -32_600, MethodNotFound = -32_601, InvalidParams = -32_602, InternalError = -32_603, TaskNotFound = -32_001, TaskNotCancelable = -32_002, PushNotificationNotSupported = -32_003, UnsupportedOperation = -32_004, ContentTypeNotSupported = -32_005, InvalidAgentResponse = -32_006, ExtendedAgentCardNotConfigured = -32_007, ExtensionSupportRequired = -32_008, VersionNotSupported = -32_009,
}
Numeric error codes defined by JSON-RPC 2.0 and the A2A v1.0 specification.

JSON-RPC standard codes occupy the -32700 to -32600 range. A2A-specific codes occupy -32001 to -32099.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ParseError = -32_700

Invalid JSON was received by the server (-32700).



InvalidRequest = -32_600

The JSON sent is not a valid Request object (-32600).



MethodNotFound = -32_601

The method does not exist or is not available (-32601).



InvalidParams = -32_602

Invalid method parameters (-32602).



InternalError = -32_603

Internal JSON-RPC error (-32603).



TaskNotFound = -32_001

The requested task was not found (-32001).



TaskNotCancelable = -32_002

The task cannot be canceled in its current state (-32002).



PushNotificationNotSupported = -32_003

The agent does not support push notifications (-32003).



UnsupportedOperation = -32_004

The requested operation is not supported by this agent (-32004).



ContentTypeNotSupported = -32_005

The requested content type is not supported (-32005).



InvalidAgentResponse = -32_006

The agent returned an invalid response (-32006).



ExtendedAgentCardNotConfigured = -32_007

Extended agent card not configured (-32007).



ExtensionSupportRequired = -32_008

A required extension is not supported (-32008).



VersionNotSupported = -32_009

The requested protocol version is not supported (-32009).

Implementations

Source

impl ErrorCode

pub const fn as_i32(self) -> i32

Returns the numeric value of this error code.

pub const fn default_message(self) -> &'static str

Returns a short human-readable description of the code.