Message types for the A2A protocol.
A Message is the fundamental communication unit between a client and an
agent. Each message has a MessageRole (ROLE_USER or ROLE_AGENT) and
carries one or more Part values.
Part type discriminator
Part uses a type field discriminator per the A2A spec:
{"type": "text", "text": "hi"}{"type": "file", "file": {"name": "f.png", "mimeType": "image/png", "bytes": "..."}}{"type": "data", "data": {...}}
Structs
- File
Content - Content of a file part.
- Message
- A message exchanged between a client and an agent.
- Message
Id - Opaque unique identifier for a
Message. - Part
- A content part within a
Messageorcrate::artifact::Artifact.
Enums
- Message
Role - The originator of a
Message. - Part
Content - The content of a
Part, discriminated by atypefield per the A2A spec.