FileContent

Struct FileContent 

pub struct FileContent {
    pub name: Option<String>,
    pub mime_type: Option<String>,
    pub bytes: Option<String>,
    pub uri: Option<String>,
}
Content of a file part.

At least one of bytes or uri should be set. Both may be set if the file is available via both inline data and a URL.

Fields

name: Option<String>

Filename (e.g. "report.pdf").

mime_type: Option<String>

MIME type (e.g. "image/png").

bytes: Option<String>

Base64-encoded file content.

uri: Option<String>

URL to the file content.

Implementations

Source

impl FileContent

pub fn from_bytes(bytes: impl Into<String>) -> FileContent

Creates a FileContent from inline base64 bytes.

pub fn from_uri(uri: impl Into<String>) -> FileContent

Creates a FileContent from a URI.

pub fn with_name(self, name: impl Into<String>) -> FileContent

Sets the filename.

pub fn with_mime_type(self, mime_type: impl Into<String>) -> FileContent

Sets the MIME type.

pub const fn validate(&self) -> Result<(), &'static str>

Validates that at least one of bytes or uri is set.

The A2A spec requires at least one content source.

Errors

Returns an error if both bytes and uri are None.