#[repr(i32)]pub enum TaskState {
Unspecified = 0,
Submitted = 1,
Working = 2,
Completed = 3,
Failed = 4,
Canceled = 5,
InputRequired = 6,
Rejected = 7,
AuthRequired = 8,
}Expand description
Defines the possible lifecycle states of a Task.
Variants
Unspecified = 0
The task is in an unknown or indeterminate state.
Submitted = 1
Indicates that a task has been successfully submitted and acknowledged.
Working = 2
Indicates that a task is actively being processed by the agent.
Completed = 3
Indicates that a task has finished successfully. This is a terminal state.
Failed = 4
Indicates that a task has finished with an error. This is a terminal state.
Canceled = 5
Indicates that a task was canceled before completion. This is a terminal state.
InputRequired = 6
Indicates that the agent requires additional user input to proceed. This is an interrupted state.
Rejected = 7
Indicates that the agent has decided to not perform the task. This may be done during initial task creation or later once an agent has determined it can’t or won’t proceed. This is a terminal state.
AuthRequired = 8
Indicates that authentication is required to proceed. This is an interrupted state.
Implementations
Sourceimpl TaskState
impl TaskState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<TaskState>
pub fn from_str_name(value: &str) -> Option<TaskState>
Creates an enum from field names used in the ProtoBuf definition.