pub struct AgentCard {Show 14 fields
pub name: String,
pub description: String,
pub supported_interfaces: Vec<AgentInterface>,
pub provider: Option<AgentProvider>,
pub version: String,
pub documentation_url: Option<String>,
pub capabilities: Option<AgentCapabilities>,
pub security_schemes: HashMap<String, SecurityScheme>,
pub security_requirements: Vec<SecurityRequirement>,
pub default_input_modes: Vec<String>,
pub default_output_modes: Vec<String>,
pub skills: Vec<AgentSkill>,
pub signatures: Vec<AgentCardSignature>,
pub icon_url: Option<String>,
}Expand description
A self-describing manifest for an agent. It provides essential metadata including the agent’s identity, capabilities, skills, supported communication methods, and security requirements. Next ID: 20
Fields
name: StringA human readable name for the agent. Example: “Recipe Agent”
description: StringA human-readable description of the agent, assisting users and other agents in understanding its purpose. Example: “Agent that helps users with recipes and cooking.”
supported_interfaces: Vec<AgentInterface>Ordered list of supported interfaces. The first entry is preferred.
provider: Option<AgentProvider>The service provider of the agent.
version: StringThe version of the agent. Example: “1.0.0”
documentation_url: Option<String>A URL providing additional documentation about the agent.
capabilities: Option<AgentCapabilities>A2A Capability set supported by the agent.
security_schemes: HashMap<String, SecurityScheme>The security scheme details used for authenticating with this agent.
security_requirements: Vec<SecurityRequirement>Security requirements for contacting the agent.
default_input_modes: Vec<String>protolint:enable REPEATED_FIELD_NAMES_PLURALIZED The set of interaction modes that the agent supports across all skills. This can be overridden per skill. Defined as media types.
default_output_modes: Vec<String>The media types supported as outputs from this agent.
skills: Vec<AgentSkill>Skills represent the abilities of an agent. It is largely a descriptive concept but represents a more focused set of behaviors that the agent is likely to succeed at.
signatures: Vec<AgentCardSignature>JSON Web Signatures computed for this AgentCard.
icon_url: Option<String>Optional. A URL to an icon for the agent.
Implementations