Push notification configuration types.
Push notifications allow an agent to deliver task updates to a client-owned
HTTPS webhook endpoint rather than requiring the client to poll. A client
registers a TaskPushNotificationConfig for a specific task via the
CreateTaskPushNotificationConfig method.
Structs
- Authentication
Info - Authentication information used by an agent when calling a push webhook.
- Task
Push Notification Config - Configuration for delivering task updates to a webhook endpoint.